@@ -17,18 +17,26 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/
 #include <stdint.h>
+#include <istream>
+
+extern "C" {
+#include "jpeglib.h"
+}
 
 namespace lightspark
 {
 
 class ImageDecoder
 {
+private:
+	static uint8_t* decodeJPEGImpl(jpeg_source_mgr& src, uint32_t* width, uint32_t* height);
 public:
 	/*
 	 * Returns a new[]'ed array of decompressed data and sets width, height and format
 	 * Return NULL on error
 	 */
 	static uint8_t* decodeJPEG(uint8_t* inData, int len, uint32_t* width, uint32_t* height);
+	static uint8_t* decodeJPEG(std::istream& str, uint32_t* width, uint32_t* height);
 };
 
 }
